@@ -29,12 +29,14 @@ class DHCPOutput:
 
         dhcp_by_server = {}
         for dhcp_lease_record in sorted(dhcp_lease_records, key = lambda dhcp_record: dhcp_record['active_address'], reverse=True):
-            server = dhcp_lease_record['server']
+            server = dhcp_lease_record.get('server', 'all')
+            if server == 'all':
+                dhcp_lease_record['server'] = server
             if server in dhcp_by_server.keys():
                 dhcp_by_server[server].append(dhcp_lease_record)
             else:
                 dhcp_by_server[server] = [dhcp_lease_record]         
-        
+
         output_records = 0
         lease_records = len(dhcp_lease_records)        
         output_entry = BaseOutputProcessor.OutputDHCPEntry
