@@ -13,11 +13,12 @@
 
 
 from collections import OrderedDict
-from mktxp.cli.config.config import MKTXPConfigKeys
 from mktxp.collector.dhcp_collector import DHCPCollector
+from mktxp.collector.connection_collector import IPConnectionCollector
 from mktxp.collector.interface_collector import InterfaceCollector
 from mktxp.collector.health_collector import HealthCollector
 from mktxp.collector.identity_collector import IdentityCollector
+from mktxp.collector.public_ip_collector import PublicIPAddressCollector
 from mktxp.collector.monitor_collector import MonitorCollector
 from mktxp.collector.poe_collector import POECollector
 from mktxp.collector.netwatch_collector import NetwatchCollector
@@ -43,8 +44,10 @@ class CollectorRegistry:
         self.register('IdentityCollector', IdentityCollector.collect)
         self.register('SystemResourceCollector', SystemResourceCollector.collect)
         self.register('HealthCollector', HealthCollector.collect)
+        self.register('PublicIPAddressCollector', PublicIPAddressCollector.collect)
 
         self.register('DHCPCollector', DHCPCollector.collect)
+        self.register('IPConnectionCollector', IPConnectionCollector.collect)
         self.register('PoolCollector', PoolCollector.collect)
         self.register('InterfaceCollector', InterfaceCollector.collect)
 
